@@ -32,24 +32,19 @@ class TestGetClientBase(object):
     def test_get_client_with_auth_token(self, mock_client, mock_load,
                                         mock_opts, mock_adapter):
         fake_token = 'token'
-        fake_ironic_url = 'http://127.0.0.1:6385'
         mock_sess = mock.Mock()
-        mock_adapter.return_value.get_endpoint.return_value = fake_ironic_url
         mock_load.return_value = mock_sess
         ir_utils.get_client(fake_token)
-        mock_adapter.assert_called_once_with(
-            'ironic', region_name='somewhere', session=mock_sess)
-        mock_adapter.return_value.get_endpoint.assert_called_once_with()
         args = {'token': fake_token,
+                'session': mock_sess,
                 'os_ironic_api_version': ir_utils.DEFAULT_IRONIC_API_VERSION,
                 'max_retries': CONF.ironic.max_retries,
                 'retry_interval': CONF.ironic.retry_interval}
-        mock_client.assert_called_once_with(1, fake_ironic_url, **args)
+        endpoint = mock_adapter.return_value.get_endpoint.return_value
+        mock_client.assert_called_once_with(1, endpoint=endpoint, **args)
 
     def test_get_client_without_auth_token(self, mock_client, mock_load,
                                            mock_opts, mock_adapter):
-        fake_ironic_url = 'http://127.0.0.1:6385'
-        mock_adapter.return_value.get_endpoint.return_value = fake_ironic_url
         mock_sess = mock.Mock()
         mock_load.return_value = mock_sess
         ir_utils.get_client(None)
@@ -57,52 +52,66 @@ class TestGetClientBase(object):
                 'os_ironic_api_version': ir_utils.DEFAULT_IRONIC_API_VERSION,
                 'max_retries': CONF.ironic.max_retries,
                 'retry_interval': CONF.ironic.retry_interval}
-        mock_client.assert_called_once_with(1, fake_ironic_url, **args)
+        endpoint = mock_adapter.return_value.get_endpoint.return_value
+        mock_client.assert_called_once_with(1, endpoint=endpoint, **args)
 
 
 @mock.patch.object(keystone, 'get_adapter')
 @mock.patch.object(keystone, 'register_auth_opts')
 @mock.patch.object(keystone, 'get_session')
-@mock.patch.object(client, 'Client')
+@mock.patch.object(client, 'get_client', autospec=True)
 class TestGetClientAuth(TestGetClientBase, base.BaseTest):
     def setUp(self):
         super(TestGetClientAuth, self).setUp()
         ir_utils.reset_ironic_session()
         self.cfg.config(auth_strategy='keystone')
-        self.cfg.config(os_region='somewhere', group='ironic')
         self.addCleanup(ir_utils.reset_ironic_session)
 
 
 @mock.patch.object(keystone, 'get_adapter')
 @mock.patch.object(keystone, 'register_auth_opts')
 @mock.patch.object(keystone, 'get_session')
-@mock.patch.object(client, 'Client')
+@mock.patch.object(client, 'get_client', autospec=True)
 class TestGetClientNoAuth(TestGetClientBase, base.BaseTest):
     def setUp(self):
         super(TestGetClientNoAuth, self).setUp()
         ir_utils.reset_ironic_session()
         self.cfg.config(auth_strategy='noauth')
-        self.cfg.config(os_region='somewhere', group='ironic')
         self.addCleanup(ir_utils.reset_ironic_session)
 
 
 class TestGetIpmiAddress(base.BaseTest):
+    def setUp(self):
+        super(TestGetIpmiAddress, self).setUp()
+        self.ipmi_address = 'www.example.com'
+        self.ipmi_ipv4 = '192.168.1.1'
+        self.ipmi_ipv6 = 'fe80::1'
+
     def test_ipv4_in_resolves(self):
         node = mock.Mock(spec=['driver_info', 'uuid'],
-                         driver_info={'ipmi_address': '192.168.1.1'})
-        ip = ir_utils.get_ipmi_address(node)
-        self.assertEqual('192.168.1.1', ip)
+                         driver_info={'ipmi_address': self.ipmi_ipv4})
+        self.assertEqual((self.ipmi_ipv4, self.ipmi_ipv4, None),
+                         ir_utils.get_ipmi_address(node))
 
-    @mock.patch('socket.gethostbyname')
+    def test_ipv6_in_resolves(self):
+        node = mock.Mock(spec=['driver_info', 'uuid'],
+                         driver_info={'ipmi_address': self.ipmi_ipv6})
+        self.assertEqual((self.ipmi_ipv6, None, self.ipmi_ipv6),
+                         ir_utils.get_ipmi_address(node))
+
+    @mock.patch('socket.getaddrinfo')
     def test_good_hostname_resolves(self, mock_socket):
         node = mock.Mock(spec=['driver_info', 'uuid'],
-                         driver_info={'ipmi_address': 'www.example.com'})
-        mock_socket.return_value = '192.168.1.1'
-        ip = ir_utils.get_ipmi_address(node)
-        mock_socket.assert_called_once_with('www.example.com')
-        self.assertEqual('192.168.1.1', ip)
+                         driver_info={'ipmi_address': self.ipmi_address})
+        mock_socket.return_value = [
+            (socket.AF_INET, None, None, None, (self.ipmi_ipv4,)),
+            (socket.AF_INET6, None, None, None, (self.ipmi_ipv6,))]
+        self.assertEqual((self.ipmi_address, self.ipmi_ipv4, self.ipmi_ipv6),
+                         ir_utils.get_ipmi_address(node))
+        mock_socket.assert_called_once_with(self.ipmi_address, None, 0, 0,
+                                            socket.SOL_TCP)
 
-    @mock.patch('socket.gethostbyname')
+    @mock.patch('socket.getaddrinfo')
     def test_bad_hostname_errors(self, mock_socket):
         node = mock.Mock(spec=['driver_info', 'uuid'],
                          driver_info={'ipmi_address': 'meow'},
@@ -112,24 +121,26 @@ class TestGetIpmiAddress(base.BaseTest):
 
     def test_additional_fields(self):
         node = mock.Mock(spec=['driver_info', 'uuid'],
-                         driver_info={'foo': '192.168.1.1'})
-        self.assertIsNone(ir_utils.get_ipmi_address(node))
+                         driver_info={'foo': self.ipmi_ipv4})
+        self.assertEqual((None, None, None),
+                         ir_utils.get_ipmi_address(node))
 
         self.cfg.config(ipmi_address_fields=['foo', 'bar', 'baz'])
-        ip = ir_utils.get_ipmi_address(node)
-        self.assertEqual('192.168.1.1', ip)
+        self.assertEqual((self.ipmi_ipv4, self.ipmi_ipv4, None),
+                         ir_utils.get_ipmi_address(node))
 
     def test_ipmi_bridging_enabled(self):
         node = mock.Mock(spec=['driver_info', 'uuid'],
                          driver_info={'ipmi_address': 'www.example.com',
                                       'ipmi_bridging': 'single'})
-        self.assertIsNone(ir_utils.get_ipmi_address(node))
+        self.assertEqual((None, None, None),
+                         ir_utils.get_ipmi_address(node))
 
     def test_loopback_address(self):
         node = mock.Mock(spec=['driver_info', 'uuid'],
                          driver_info={'ipmi_address': '127.0.0.2'})
-        ip = ir_utils.get_ipmi_address(node)
-        self.assertIsNone(ip)
+        self.assertEqual((None, None, None),
+                         ir_utils.get_ipmi_address(node))
 
 
 class TestCapabilities(unittest.TestCase):
