@@ -11,10 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import json
+
 import fixtures
+from ironic_lib import mdns
 import mock
 import oslo_messaging as messaging
 
+from ironic_inspector.common import keystone
+from ironic_inspector.common import swift
 from ironic_inspector.conductor import manager
 import ironic_inspector.conf
 from ironic_inspector import introspect
@@ -96,12 +101,14 @@ class TestManagerInitHost(BaseManagerTest):
             'Introspection data will not be stored. Change "[processing] '
             'store_data" option if this is not the desired behavior')
 
-    def test_init_host(self):
+    @mock.patch.object(mdns, 'Zeroconf', autospec=True)
+    def test_init_host(self, mock_zc):
         self.manager.init_host()
-        self.mock_db_init.asset_called_once_with()
+        self.mock_db_init.assert_called_once_with()
         self.mock_validate_processing_hooks.assert_called_once_with()
         self.mock_filter.init_filter.assert_called_once_with()
         self.assert_periodics()
+        self.assertFalse(mock_zc.called)
 
     def test_init_host_validate_processing_hooks_exception(self):
         class MyError(Exception):
@@ -120,6 +127,18 @@ class TestManagerInitHost(BaseManagerTest):
         self.mock_exit.assert_called_once_with(1)
         self.mock_filter.init_filter.assert_not_called()
 
+    @mock.patch.object(mdns, 'Zeroconf', autospec=True)
+    @mock.patch.object(keystone, 'get_endpoint', autospec=True)
+    def test_init_host_with_mdns(self, mock_endpoint, mock_zc):
+        CONF.set_override('enable_mdns', True)
+        self.manager.init_host()
+        self.mock_db_init.assert_called_once_with()
+        self.mock_validate_processing_hooks.assert_called_once_with()
+        self.mock_filter.init_filter.assert_called_once_with()
+        self.assert_periodics()
+        mock_zc.return_value.register_service.assert_called_once_with(
+            'baremetal-introspection', mock_endpoint.return_value)
+
 
 class TestManagerDelHost(BaseManagerTest):
     def setUp(self):
@@ -148,6 +167,23 @@ class TestManagerDelHost(BaseManagerTest):
         self.mock_filter.tear_down_filter.assert_called_once_with()
         self.mock__shutting_down.release.assert_called_once_with()
 
+    def test_del_host_with_mdns(self):
+        mock_zc = mock.Mock(spec=mdns.Zeroconf)
+        self.manager._zeroconf = mock_zc
+
+        self.manager.del_host()
+
+        mock_zc.close.assert_called_once_with()
+        self.assertIsNone(self.manager._zeroconf)
+        self.mock__shutting_down.acquire.assert_called_once_with(
+            blocking=False)
+        self.mock__periodic_worker.stop.assert_called_once_with()
+        self.mock__periodic_worker.wait.assert_called_once_with()
+        self.assertIsNone(self.manager._periodics_worker)
+        self.mock_executor.shutdown.assert_called_once_with(wait=True)
+        self.mock_filter.tear_down_filter.assert_called_once_with()
+        self.mock__shutting_down.release.assert_called_once_with()
+
     def test_del_host_race(self):
         self.mock__shutting_down.acquire.return_value = False
 
@@ -302,11 +338,17 @@ class TestManagerReapply(BaseManagerTest):
         super(TestManagerReapply, self).setUp()
         CONF.set_override('store_data', 'swift', 'processing')
 
-    def test_ok(self, reapply_mock):
+    @mock.patch.object(swift, 'store_introspection_data', autospec=True)
+    @mock.patch.object(swift, 'get_introspection_data', autospec=True)
+    def test_ok(self, swift_get_mock, swift_set_mock, reapply_mock):
+        swift_get_mock.return_value = json.dumps(self.data)
         self.manager.do_reapply(self.context, self.uuid)
-        reapply_mock.assert_called_once_with(self.uuid)
+        reapply_mock.assert_called_once_with(self.uuid, data=self.data)
 
-    def test_node_locked(self, reapply_mock):
+    @mock.patch.object(swift, 'store_introspection_data', autospec=True)
+    @mock.patch.object(swift, 'get_introspection_data', autospec=True)
+    def test_node_locked(self, swift_get_mock, swift_set_mock, reapply_mock):
+        swift_get_mock.return_value = json.dumps(self.data)
         exc = utils.Error('Locked.', code=409)
         reapply_mock.side_effect = exc
 
@@ -317,9 +359,13 @@ class TestManagerReapply(BaseManagerTest):
         self.assertEqual(utils.Error, exc.exc_info[0])
         self.assertIn('Locked.', str(exc.exc_info[1]))
         self.assertEqual(409, exc.exc_info[1].http_code)
-        reapply_mock.assert_called_once_with(self.uuid)
+        reapply_mock.assert_called_once_with(self.uuid, data=self.data)
 
-    def test_node_not_found(self, reapply_mock):
+    @mock.patch.object(swift, 'store_introspection_data', autospec=True)
+    @mock.patch.object(swift, 'get_introspection_data', autospec=True)
+    def test_node_not_found(self, swift_get_mock, swift_set_mock,
+                            reapply_mock):
+        swift_get_mock.return_value = json.dumps(self.data)
         exc = utils.Error('Not found.', code=404)
         reapply_mock.side_effect = exc
 
@@ -330,9 +376,11 @@ class TestManagerReapply(BaseManagerTest):
         self.assertEqual(utils.Error, exc.exc_info[0])
         self.assertIn('Not found.', str(exc.exc_info[1]))
         self.assertEqual(404, exc.exc_info[1].http_code)
-        reapply_mock.assert_called_once_with(self.uuid)
+        reapply_mock.assert_called_once_with(self.uuid, data=self.data)
 
-    def test_generic_error(self, reapply_mock):
+    @mock.patch.object(process, 'get_introspection_data', autospec=True)
+    def test_generic_error(self, get_data_mock, reapply_mock):
+        get_data_mock.return_value = self.data
         exc = utils.Error('Oops', code=400)
         reapply_mock.side_effect = exc
 
@@ -343,4 +391,61 @@ class TestManagerReapply(BaseManagerTest):
         self.assertEqual(utils.Error, exc.exc_info[0])
         self.assertIn('Oops', str(exc.exc_info[1]))
         self.assertEqual(400, exc.exc_info[1].http_code)
-        reapply_mock.assert_called_once_with(self.uuid)
+        reapply_mock.assert_called_once_with(self.uuid, data=self.data)
+        get_data_mock.assert_called_once_with(self.uuid, processed=False,
+                                              get_json=True)
+
+    @mock.patch.object(process, 'get_introspection_data', autospec=True)
+    def test_get_introspection_data_error(self, get_data_mock, reapply_mock):
+        exc = utils.Error('The store is empty', code=404)
+        get_data_mock.side_effect = exc
+
+        exc = self.assertRaises(messaging.rpc.ExpectedException,
+                                self.manager.do_reapply,
+                                self.context, self.uuid)
+
+        self.assertEqual(utils.Error, exc.exc_info[0])
+        self.assertIn('The store is empty', str(exc.exc_info[1]))
+        self.assertEqual(404, exc.exc_info[1].http_code)
+        get_data_mock.assert_called_once_with(self.uuid, processed=False,
+                                              get_json=True)
+        self.assertFalse(reapply_mock.called)
+
+    def test_store_data_disabled(self, reapply_mock):
+        CONF.set_override('store_data', 'none', 'processing')
+
+        exc = self.assertRaises(messaging.rpc.ExpectedException,
+                                self.manager.do_reapply,
+                                self.context, self.uuid)
+
+        self.assertEqual(utils.Error, exc.exc_info[0])
+        self.assertIn('Inspector is not configured to store introspection '
+                      'data', str(exc.exc_info[1]))
+        self.assertEqual(400, exc.exc_info[1].http_code)
+        self.assertFalse(reapply_mock.called)
+
+    @mock.patch.object(process, 'get_introspection_data', autospec=True)
+    def test_ok_swift(self, get_data_mock, reapply_mock):
+        get_data_mock.return_value = self.data
+        self.manager.do_reapply(self.context, self.uuid)
+        reapply_mock.assert_called_once_with(self.uuid, data=self.data)
+        get_data_mock.assert_called_once_with(self.uuid, processed=False,
+                                              get_json=True)
+
+    @mock.patch.object(process, 'get_introspection_data', autospec=True)
+    def test_ok_db(self, get_data_mock, reapply_mock):
+        get_data_mock.return_value = self.data
+        CONF.set_override('store_data', 'database', 'processing')
+        self.manager.do_reapply(self.context, self.uuid)
+        reapply_mock.assert_called_once_with(self.uuid, data=self.data)
+        get_data_mock.assert_called_once_with(self.uuid, processed=False,
+                                              get_json=True)
+
+    @mock.patch.object(process, 'store_introspection_data', autospec=True)
+    @mock.patch.object(process, 'get_introspection_data', autospec=True)
+    def test_reapply_with_data(self, get_mock, store_mock, reapply_mock):
+        self.manager.do_reapply(self.context, self.uuid, data=self.data)
+        reapply_mock.assert_called_once_with(self.uuid, data=self.data)
+        store_mock.assert_called_once_with(self.uuid, self.data,
+                                           processed=False)
+        self.assertFalse(get_mock.called)
