@@ -89,8 +89,9 @@ class TestProcess(BaseProcessTest):
 
         self.assertEqual(self.fake_result_json, res)
 
-        self.find_mock.assert_called_once_with(bmc_address=self.bmc_address,
-                                               mac=mock.ANY)
+        self.find_mock.assert_called_once_with(
+            bmc_address=[self.bmc_address, self.bmc_v6address],
+            mac=mock.ANY)
         actual_macs = self.find_mock.call_args[1]['mac']
         self.assertEqual(sorted(self.all_macs), sorted(actual_macs))
         self.cli.node.get.assert_called_once_with(self.uuid)
@@ -99,9 +100,11 @@ class TestProcess(BaseProcessTest):
 
     def test_no_ipmi(self):
         del self.inventory['bmc_address']
+        del self.inventory['bmc_v6address']
         process.process(self.data)
 
-        self.find_mock.assert_called_once_with(bmc_address=None, mac=mock.ANY)
+        self.find_mock.assert_called_once_with(bmc_address=[None, None],
+                                               mac=mock.ANY)
         actual_macs = self.find_mock.call_args[1]['mac']
         self.assertEqual(sorted(self.all_macs), sorted(actual_macs))
         self.cli.node.get.assert_called_once_with(self.uuid)
@@ -110,9 +113,11 @@ class TestProcess(BaseProcessTest):
 
     def test_ipmi_not_detected(self):
         self.inventory['bmc_address'] = '0.0.0.0'
+        self.inventory['bmc_v6address'] = '::/0'
         process.process(self.data)
 
-        self.find_mock.assert_called_once_with(bmc_address=None, mac=mock.ANY)
+        self.find_mock.assert_called_once_with(bmc_address=[None, None],
+                                               mac=mock.ANY)
         actual_macs = self.find_mock.call_args[1]['mac']
         self.assertEqual(sorted(self.all_macs), sorted(actual_macs))
         self.cli.node.get.assert_called_once_with(self.uuid)
@@ -124,7 +129,9 @@ class TestProcess(BaseProcessTest):
         self.data['ipmi_address'] = '0.0.0.0'
         process.process(self.data)
 
-        self.find_mock.assert_called_once_with(bmc_address=None, mac=mock.ANY)
+        self.find_mock.assert_called_once_with(
+            bmc_address=[None, self.bmc_v6address],
+            mac=mock.ANY)
         actual_macs = self.find_mock.call_args[1]['mac']
         self.assertEqual(sorted(self.all_macs), sorted(actual_macs))
         self.cli.node.get.assert_called_once_with(self.uuid)
@@ -426,6 +433,30 @@ class TestProcessNode(BaseTest):
         post_hook_mock.assert_called_once_with(self.data, self.node_info)
         finished_mock.assert_called_once_with(mock.ANY, istate.Events.finish)
 
+    @mock.patch.object(example_plugin.ExampleProcessingHook, 'before_update',
+                       autospec=True)
+    @mock.patch.object(node_cache.NodeInfo, 'finished', autospec=True)
+    def test_ok_node_active(self, finished_mock, post_hook_mock):
+        self.node.provision_state = 'active'
+        CONF.set_override('permit_active_introspection', True, 'processing')
+        process._process_node(self.node_info, self.node, self.data)
+
+        self.cli.port.create.assert_any_call(node_uuid=self.uuid,
+                                             address=self.macs[0],
+                                             extra={},
+                                             pxe_enabled=True)
+        self.cli.port.create.assert_any_call(node_uuid=self.uuid,
+                                             address=self.macs[1],
+                                             extra={},
+                                             pxe_enabled=False)
+
+        self.cli.node.set_power_state.assert_not_called()
+        self.assertFalse(self.cli.node.validate.called)
+
+        post_hook_mock.assert_called_once_with(mock.ANY, self.data,
+                                               self.node_info)
+        finished_mock.assert_called_once_with(mock.ANY, istate.Events.finish)
+
     def test_port_failed(self):
         self.cli.port.create.side_effect = (
             [exceptions.Conflict()] + self.ports[1:])
@@ -546,7 +577,7 @@ class TestReapply(BaseTest):
     @prepare_mocks
     def test_ok(self, pop_mock, reapply_mock):
         process.reapply(self.uuid)
-        pop_mock.assert_called_once_with(self.uuid, locked=False)
+        pop_mock.assert_called_once_with(self.uuid)
         pop_mock.return_value.acquire_lock.assert_called_once_with(
             blocking=False
         )
@@ -561,7 +592,7 @@ class TestReapply(BaseTest):
                                'Node locked, please, try again later',
                                process.reapply, self.uuid)
 
-        pop_mock.assert_called_once_with(self.uuid, locked=False)
+        pop_mock.assert_called_once_with(self.uuid)
         pop_mock.return_value.acquire_lock.assert_called_once_with(
             blocking=False
         )
@@ -569,7 +600,7 @@ class TestReapply(BaseTest):
     @prepare_mocks
     def test_reapply_with_data(self, pop_mock, reapply_mock):
         process.reapply(self.uuid, data=self.data)
-        pop_mock.assert_called_once_with(self.uuid, locked=False)
+        pop_mock.assert_called_once_with(self.uuid)
         pop_mock.return_value.acquire_lock.assert_called_once_with(
             blocking=False
         )
