@@ -23,7 +23,6 @@ from oslo_middleware import cors as cors_middleware
 import pytz
 
 from ironic_inspector.common.i18n import _
-from ironic_inspector import conf  # noqa
 from ironic_inspector import policy
 
 CONF = cfg.CONF
@@ -44,6 +43,19 @@ def get_ipmi_address_from_data(introspection_data):
         return result
 
 
+def get_ipmi_v6address_from_data(introspection_data):
+    try:
+        result = introspection_data['inventory']['bmc_v6address']
+    except KeyError:
+        result = introspection_data.get('ipmi_v6address')
+
+    if result in ('', '::/0'):
+        # ipmitool can return these values, if it does not know the address
+        return None
+    else:
+        return result
+
+
 def get_pxe_mac(introspection_data):
     pxe_mac = introspection_data.get('boot_interface')
     if pxe_mac and '-' in pxe_mac:
@@ -141,6 +153,14 @@ class NodeStateInvalidEvent(Error):
     """Invalid event attempted."""
 
 
+class IntrospectionDataStoreDisabled(Error):
+    """Introspection data store is disabled."""
+
+
+class IntrospectionDataNotFound(NotFoundInCacheError):
+    """Introspection data not found."""
+
+
 def executor():
     """Return the current futures executor."""
     global _EXECUTOR
@@ -195,9 +215,6 @@ def get_valid_macs(data):
             if m.get('mac')]
 
 
-_INVENTORY_MANDATORY_KEYS = ('memory', 'cpu', 'interfaces')
-
-
 def get_inventory(data, node_info=None):
     """Get and validate the hardware inventory from introspection data."""
     inventory = data.get('inventory')
@@ -206,10 +223,9 @@ def get_inventory(data, node_info=None):
         raise Error(_('Hardware inventory is empty or missing'),
                     data=data, node_info=node_info)
 
-    for key in _INVENTORY_MANDATORY_KEYS:
-        if not inventory.get(key):
-            raise Error(_('Invalid hardware inventory: %s key is missing '
-                          'or empty') % key, data=data, node_info=node_info)
+    if not inventory.get('interfaces'):
+        raise Error(_('No network interfaces provided in the inventory'),
+                    data=data, node_info=node_info)
 
     if not inventory.get('disks'):
         LOG.info('No disks were detected in the inventory, assuming this '
